@@ -107,7 +107,7 @@ void PackageManagerImpl::Lock(chrono::milliseconds timeout)
 {
   if (lockFile == nullptr)
   {
-    lockFile = LockFile::Create(session->GetSpecialPath(SpecialPath::InstallRoot) / MIKTEX_PATH_PACKAGE_MANAGER_LOCK);
+    lockFile = LockFile::Create(session->GetSpecialPath(SpecialPath::InstallRoot) / PathName(MIKTEX_PATH_PACKAGE_MANAGER_LOCK));
   }
   if (!lockFile->TryLock(timeout))
   {
@@ -142,14 +142,20 @@ unique_ptr<PackageIterator> PackageManagerImpl::CreateIterator()
 void PackageManagerImpl::LoadDatabase(const PathName& path, bool isArchive)
 {
   PathName absPath(path);
-  absPath.MakeAbsolute();
+  absPath.MakeFullyQualified();
 
   unique_ptr<TemporaryDirectory> tempDir;
 
   PathName packageManifestsPath;
 
+  bool mustBeSigned = false;
+
   if (isArchive)
   {
+#if defined(WITH_PACKAGE_DB_SIGNING)
+    mustBeSigned = true;
+#endif
+
     // create temporary directory
     tempDir = TemporaryDirectory::Create();
 
@@ -157,16 +163,17 @@ void PackageManagerImpl::LoadDatabase(const PathName& path, bool isArchive)
     unique_ptr<MiKTeX::Extractor::Extractor> extractor(MiKTeX::Extractor::Extractor::CreateExtractor(DB_ARCHIVE_FILE_TYPE));
     extractor->Extract(absPath, tempDir->GetPathName());
 
-    packageManifestsPath = tempDir->GetPathName() / MIKTEX_PACKAGE_MANIFESTS_INI_FILENAME;
+    packageManifestsPath = tempDir->GetPathName() / PathName(MIKTEX_PACKAGE_MANIFESTS_INI_FILENAME);
   }
   else
   {
+    mustBeSigned = false;
     packageManifestsPath = absPath;
   }
 
   // load "package-manifests.ini"
   packageDataStore.Clear();
-  packageDataStore.LoadAllPackageManifests(packageManifestsPath);
+  packageDataStore.LoadAllPackageManifests(packageManifestsPath, mustBeSigned);
 }
 
 void PackageManagerImpl::ClearAll()
@@ -375,11 +382,11 @@ void PackageManager::SetDefaultPackageRepository(const RepositoryInfo& repositor
   {
   case RepositoryType::MiKTeXDirect:
     repositoryTypeStr = "direct";
-    SetMiKTeXDirectRoot(repository.url);
+    SetMiKTeXDirectRoot(PathName(repository.url));
     break;
   case RepositoryType::Local:
     repositoryTypeStr = "local";
-    SetLocalPackageRepository(repository.url);
+    SetLocalPackageRepository(PathName(repository.url));
     break;
   case RepositoryType::Remote:
     repositoryTypeStr = "remote";
@@ -425,14 +432,16 @@ MPMSTATICFUNC(void) RememberFileNameInfo(const string& prefixedFileName, const s
 {
   shared_ptr<Session> session = Session::Get();
 
-  string fileName;
+  string unprefixed;
 
   // ignore non-texmf files
-  if (!PackageManager::StripTeXMFPrefix(prefixedFileName, fileName))
+  if (!PackageManager::StripTeXMFPrefix(prefixedFileName, unprefixed))
   {
     return;
   }
 
+  PathName fileName(unprefixed);
+
   PathNameParser pathtok(fileName);
 
   if (!pathtok)
@@ -442,7 +451,7 @@ MPMSTATICFUNC(void) RememberFileNameInfo(const string& prefixedFileName, const s
 
   // initialize root path: "//MiKTeX/[MPM]"
   PathName path = session->GetMpmRootPath();
-  //  path += CURRENT_DIRECTORY;
+  // path += CURRENT_DIRECTORY;
 
   // s1: current path name component
   string s1 = *pathtok;
@@ -526,8 +535,8 @@ bool PackageManager::IsLocalPackageRepository(const PathName& path)
   }
 
   // local mirror of remote package repository?
-  PathName file1 = PathName(path, MIKTEX_REPOSITORY_MANIFEST_ARCHIVE_FILE_NAME);
-  PathName file2 = PathName(path, MIKTEX_PACKAGE_MANIFESTS_ARCHIVE_FILE_NAME);
+  PathName file1 = PathName(path, PathName(MIKTEX_REPOSITORY_MANIFEST_ARCHIVE_FILE_NAME));
+  PathName file2 = PathName(path, PathName(MIKTEX_PACKAGE_MANIFESTS_ARCHIVE_FILE_NAME));
   if (File::Exists(file1) && File::Exists(file2))
   {
     return true;
@@ -953,7 +962,7 @@ PackageInfo PackageManager::GetPackageManifest(const Cfg& cfg, const string& pac
 #if defined(MIKTEX_UNIX)
         path.ConvertToUnix();
 #endif
-        if (texmfPrefix.empty() || (PathName::Compare(texmfPrefix, path, texmfPrefix.length()) == 0))
+        if (texmfPrefix.empty() || (PathName::Compare(PathName(texmfPrefix), path, texmfPrefix.length()) == 0))
         {
           packageInfo.runFiles.push_back(path.ToString());
         }
@@ -971,7 +980,7 @@ PackageInfo PackageManager::GetPackageManifest(const Cfg& cfg, const string& pac
 #if defined(MIKTEX_UNIX)
         path.ConvertToUnix();
 #endif
-        if (texmfPrefix.empty() || (PathName::Compare(texmfPrefix, path, texmfPrefix.length()) == 0))
+        if (texmfPrefix.empty() || (PathName::Compare(PathName(texmfPrefix), path, texmfPrefix.length()) == 0))
         {
           packageInfo.docFiles.push_back(path.ToString());
         }
@@ -989,7 +998,7 @@ PackageInfo PackageManager::GetPackageManifest(const Cfg& cfg, const string& pac
 #if defined(MIKTEX_UNIX)
         path.ConvertToUnix();
 #endif
-        if (texmfPrefix.empty() || (PathName::Compare(texmfPrefix, path, texmfPrefix.length()) == 0))
+        if (texmfPrefix.empty() || (PathName::Compare(PathName(texmfPrefix), path, texmfPrefix.length()) == 0))
         {
           packageInfo.sourceFiles.push_back(path.ToString());
         }
@@ -1172,7 +1181,7 @@ string PackageManagerImpl::GetContainerPathNoLock(const string& packageId, bool
     {
       // RECUSION
       path = GetContainerPathNoLock(reqby, useDisplayNames);
-      path += PathName::DirectoryDelimiter;
+      path += PathNameUtil::DirectoryDelimiter;
       if (useDisplayNames)
       {
         path += packageInfo2.displayName;
