@@ -22,6 +22,7 @@
 #include <fmt/format.h>
 #include <fmt/ostream.h>
 
+#include <miktex/Core/AutoResource>
 #include <miktex/Core/ConfigNames>
 #include <miktex/Core/Directory>
 #include <miktex/Core/Paths>
@@ -29,10 +30,34 @@
 
 #include <miktex/Trace/Trace>
 
+#if defined(MIKTEX_TEXMF_SHARED)
+#  define C4PEXPORT MIKTEXDLLEXPORT
+#else
+#  define C4PEXPORT
+#endif
+#define C1F0C63F01D5114A90DDF8FC10FF410B
+#include "miktex/C4P/C4P.h"
+
+#if defined(MIKTEX_TEXMF_SHARED)
+#  define MIKTEXMFEXPORT MIKTEXDLLEXPORT
+#else
+#  define MIKTEXMFEXPORT
+#endif
+#define B8C7815676699B4EA2DE96F0BD727276
+#include "miktex/TeXAndFriends/TeXMFApp.h"
+
 #include "internal.h"
 
 #include "miktex/texmfapp.defaults.h"
 
+using namespace std;
+
+using namespace MiKTeX::Core;
+using namespace MiKTeX::TeXAndFriends;
+using namespace MiKTeX::Trace;
+using namespace MiKTeX::Util;
+using namespace MiKTeX::Wrappers;
+
 class TeXMFApp::impl
 {
 public:
@@ -137,9 +162,6 @@ void TeXMFApp::Init(vector<char*>& args)
   pimpl->interactionMode = -1;
   pimpl->isInitProgram = false;
   pimpl->isUnicodeApp = AmI("xetex");
-#if defined(WITH_OMEGA)
-  pimpl->isUnicodeApp = pimpl->isUnicodeApp || AmI("omega");
-#endif
   pimpl->parseFirstLine = false;
   pimpl->recordFileNames = false;
   pimpl->setJobTime = false;
@@ -439,12 +461,6 @@ bool TeXMFApp::ProcessOption(int opt, const string& optArg)
     {
       pimpl->jobName = optArg;
     }
-#if defined(WITH_OMEGA)
-    else if (AmI("omega"))
-    {
-      pimpl->jobName = MangleNameOfFile(optArg.c_str()).GetData();
-    }
-#endif
     else
     {
       pimpl->jobName = Q_(optArg);
@@ -470,7 +486,7 @@ bool TeXMFApp::ProcessOption(int opt, const string& optArg)
       File::GetTimes(PathName(optArg), creationTime, lastAccessTime, lastWriteTime);
       jobTime = lastWriteTime;
     }
-    SetStartUpTime(jobTime, false);
+    GetProgram()->SetStartUpTime(jobTime, false);
     pimpl->setJobTime = true;
   }
   break;
@@ -598,8 +614,8 @@ bool inParseFirstLine = false;
 
 void TeXMFApp::CheckFirstLine(const PathName& fileName)
 {
-  AutoRestore<bool> autoRestoreInParseFirstLine(inParseFirstLine);
   inParseFirstLine = true;
+  MIKTEX_AUTO(inParseFirstLine = false);
 
   PathName path;
 
@@ -744,13 +760,13 @@ void TeXMFApp::ProcessCommandLineOptions()
   }
 
   if (pimpl->parseFirstLine
-    && GetArgC() > 1
-    && GetArgV()[1][0] != '&'
-    && GetArgV()[1][0] != '*' // <fixme/>
-    && GetArgV()[1][0] != '\\'
+    && GetProgram()->GetArgC() > 1
+    && GetProgram()->GetArgV()[1][0] != '&'
+    && GetProgram()->GetArgV()[1][0] != '*' // <fixme/>
+    && GetProgram()->GetArgV()[1][0] != '\\'
     && (pimpl->memoryDumpFileName.empty() || GetTcxFileName().Empty()))
   {
-    CheckFirstLine(PathName(GetArgV()[1]));
+    CheckFirstLine(PathName(GetProgram()->GetArgV()[1]));
   }
 }
 
@@ -831,6 +847,9 @@ void TeXMFApp::InitializeBuffer() const
 
   shared_ptr<Session> session = Session::Get();
 
+  auto argc = GetProgram()->GetArgC();
+  auto argv = GetProgram()->GetArgV();
+
   if (AmITeX())
   {
     /* test command-line for one of:
@@ -840,31 +859,24 @@ void TeXMFApp::InitializeBuffer() const
     (d) initex &FORMAT FILENAME \dump
     */
     PathName path;
-    if (c4pargc == 2 && IsFileNameArgument(c4pargv[1]) && session->FindFile(c4pargv[1], GetInputFileType(), path))
+    if (argc == 2 && IsFileNameArgument(argv[1]) && session->FindFile(argv[1], GetInputFileType(), path))
     {
       fileNameArgIdx = 1;
     }
-    else if (c4pargc == 3 && c4pargv[1][0] == '&' && IsFileNameArgument(c4pargv[2]) && session->FindFile(c4pargv[2], GetInputFileType(), path))
+    else if (argc == 3 && argv[1][0] == '&' && IsFileNameArgument(argv[2]) && session->FindFile(argv[2], GetInputFileType(), path))
     {
       fileNameArgIdx = 2;
     }
-    else if (c4pargc == 3 && strcmp(c4pargv[2], "\\dump") == 0 && IsFileNameArgument(c4pargv[1]) && session->FindFile(c4pargv[1], GetInputFileType(), path))
+    else if (argc == 3 && strcmp(argv[2], "\\dump") == 0 && IsFileNameArgument(argv[1]) && session->FindFile(argv[1], GetInputFileType(), path))
     {
       fileNameArgIdx = 1;
     }
-    else if (c4pargc == 4 && c4pargv[1][0] == '&' && strcmp(c4pargv[3], "\\dump") == 0 && IsFileNameArgument(c4pargv[2]) && session->FindFile(c4pargv[2], GetInputFileType(), path))
+    else if (argc == 4 && argv[1][0] == '&' && strcmp(argv[3], "\\dump") == 0 && IsFileNameArgument(argv[2]) && session->FindFile(argv[2], GetInputFileType(), path))
     {
       fileNameArgIdx = 2;
     }
     if (fileNameArgIdx >= 0)
     {
-#if defined(WITH_OMEGA)
-      if (AmI("omega"))
-      {
-        fileName = WebAppInputLine::MangleNameOfFile(c4pargv[fileNameArgIdx]);
-      }
-      else
-#endif
 #if defined(MIKTEX_WINDOWS)
         fileName = Q_(path.ToUnix());
 #else
@@ -874,14 +886,11 @@ void TeXMFApp::InitializeBuffer() const
   }
 
   //MIKTEX_ASSERT(inout->first() == 1);
-  C4P_signed32& last = inout->last();
+  C4P::C4P_signed32& last = inout->last();
   last = 1;
   char32_t* buffer32 = AmI("xetex") ? inout->buffer32() : nullptr;
-#if defined(WITH_OMEGA)
-  char16_t* buffer16 = AmI("omega") ? inout->buffer16() : nullptr;
-#endif
   char*buffer = !IsUnicodeApp() ? inout->buffer() : nullptr;
-  for (int idx = 1; idx < c4pargc; ++idx)
+  for (int idx = 1; idx < argc; ++idx)
   {
     if (idx > 1)
     {
@@ -889,12 +898,6 @@ void TeXMFApp::InitializeBuffer() const
       {
         buffer32[last++] = U' ';
       }
-#if defined(WITH_OMEGA)
-      else if (AmI("omega"))
-      {
-        buffer16[last++] = u' ';
-      }
-#endif
       else
       {
         buffer[last++] = ' ';
@@ -907,7 +910,7 @@ void TeXMFApp::InitializeBuffer() const
     }
     else
     {
-      lpszOptArg = c4pargv[idx];
+      lpszOptArg = argv[idx];
     }
     if (AmI("xetex"))
     {
@@ -916,15 +919,6 @@ void TeXMFApp::InitializeBuffer() const
         buffer32[last++] = ch;
       }
     }
-#if defined(WITH_OMEGA)
-    else if (AmI("omega"))
-    {
-      for (const char16_t& ch : StringUtil::UTF8ToUTF16(lpszOptArg))
-      {
-        buffer16[last++] = ch;
-      }
-    }
-#endif
     else
     {
       for (const char* lpsz = lpszOptArg; *lpsz != 0; ++lpsz)
@@ -935,7 +929,7 @@ void TeXMFApp::InitializeBuffer() const
   }
 
   // clear the command-line
-  MakeCommandLine(vector<string>());
+  GetProgram()->MakeCommandLine(vector<string>());
 }
 
 void TeXMFApp::TouchJobOutputFile(FILE* file) const
@@ -944,7 +938,7 @@ void TeXMFApp::TouchJobOutputFile(FILE* file) const
   shared_ptr<Session> session = GetSession();
   if (pimpl->setJobTime && session->IsOutputFile(file))
   {
-    time_t time = GetStartUpTime();
+    time_t time = GetProgram()->GetStartUpTime();
     File::SetTimes(file, time, time, time);
   }
 }
@@ -1046,14 +1040,20 @@ int TeXMFApp::MakeTeXString(const char* lpsz) const
     CheckPoolPointer(stringHandler->poolptr(), len);
     memcpy(stringHandler->strpool() + stringHandler->poolptr(), lpsz, len * sizeof(char));
   }
-  stringHandler->poolptr() += static_cast<C4P_signed32>(len);
+  stringHandler->poolptr() += static_cast<C4P::C4P_signed32>(len);
   return stringHandler->makestring();
 }
 
-int TeXMFApp::GetJobName() const
+int TeXMFApp::GetJobName(int fallbackJobName) const
 {
   if (pimpl->jobName.empty())
   {
+    if (GetLastInputFileName().Empty())
+    {
+      pimpl->jobName = GetTeXString(fallbackJobName);
+      MIKTEX_EXPECT(pimpl->jobName.find(' ') == string::npos);
+      return fallbackJobName;
+    }
     PathName name = GetLastInputFileName().GetFileNameWithoutExtension();
     if (AmI("xetex"))
     {
