@@ -1501,6 +1501,13 @@ void ParseList(const string& s, vector<string>& list)
 
 void Application::Main(int argc, const char** argv)
 {
+#if defined(MIKTEX_WINDOWS)
+  UINT activeOutputCodePage = GetConsoleOutputCP();
+  if (activeOutputCodePage != CP_UTF8)
+  {
+    SetConsoleOutputCP(CP_UTF8);
+  }
+#endif
   bool optAdmin = false;
   bool optCheckRepositories = false;
   bool optFindConflicts = false;
@@ -1850,8 +1857,10 @@ void Application::Main(int argc, const char** argv)
   if (optVersion)
   {
     cout
-      << Utils::MakeProgramVersionString(THE_NAME_OF_THE_GAME, VersionNumber(MIKTEX_MAJOR_VERSION, MIKTEX_MINOR_VERSION, MIKTEX_COMP_J2000_VERSION, 0)) << endl
-      << "Copyright (C) 2005-2020 Christian Schenk" << endl
+      << Utils::MakeProgramVersionString(THE_NAME_OF_THE_GAME, VersionNumber(MIKTEX_COMPONENT_VERSION_STR)) << endl
+      << endl
+      << MIKTEX_COMP_COPYRIGHT_STR << endl
+      << endl
       << "This is free software; see the source for copying conditions.  There is NO" << endl
       << "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE." << endl;
     return;
@@ -1902,6 +1911,12 @@ void Application::Main(int argc, const char** argv)
     }
     LOG4CXX_INFO(logger, "this is " << Utils::MakeProgramVersionString("mpmcli", VersionNumber(MIKTEX_COMPONENT_VERSION_STR)));
     LOG4CXX_INFO(logger, "this process (" << thisProcess->GetSystemId() << ") started by '" << invokerName << "' with command line: " << CommandLineBuilder(argc, argv));
+#if defined(MIKTEX_WINDOWS)
+    if (activeOutputCodePage != CP_UTF8)
+    {
+      LOG4CXX_DEBUG(logger, fmt::format("changed console output code page from {0} to {1}", activeOutputCodePage, GetConsoleOutputCP()));
+    }
+#endif
   }
 
   if (session->IsAdminMode())
