@@ -40,6 +40,8 @@
 #include <memory>
 #include <vector>
 
+#include "mcd-version.h"
+
 #include <miktex/App/Application>
 #include <miktex/Core/BufferSizes>
 #include <miktex/Core/CommandLineBuilder>
@@ -68,8 +70,6 @@
 
 #include <regex.h>
 
-#include "mcd-version.h"
-
 using namespace std;
 using namespace std::string_literals;
 
@@ -559,10 +559,10 @@ void McdApp::MyTrace(const string& s)
 void McdApp::Version()
 {
   cout
-    << Utils::MakeProgramVersionString(THE_NAME_OF_THE_GAME, VersionNumber(MIKTEX_MAJOR_VERSION, MIKTEX_MINOR_VERSION, MIKTEX_COMP_J2000_VERSION, 0)) << "\n"
-    << "Copyright (C) 1998-2020 Christian Schenk" << "\n"
-    << "Copyright (C) 1992, 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2001," << "\n"
-    << "2002, 2003, 2004, 2005 Free Software Foundation, Inc." << "\n"
+    << Utils::MakeProgramVersionString(THE_NAME_OF_THE_GAME, VersionNumber(MIKTEX_COMPONENT_VERSION_STR)) << "\n"
+    << "\n"
+    << MIKTEX_COMP_COPYRIGHT_STR
+    << "\n"
     << "This is free software; see the source for copying conditions.  There is NO" << "\n"
     << "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE." << "\n";
 }
