@@ -20,8 +20,7 @@
 #define MIKTEX_COMP_J2000_VERSION 7439
 #define MIKTEX_COMP_ORIG_VERSION_STR "2.718281"
 
-#define MIKTEX_COMP_COPYRIGHT_STR "Copyright (C) 1984 by D. E. Knuth"
-#define MIKTEX_COMP_COPYRIGHT_STR_1252 " 1984 by D. E. Knuth"
-#define MIKTEX_COMP_TM_STR "METAFONT is a trademark of Addison-Wesley Publishing Company."
+#define MIKTEX_COMP_COPYRIGHT_STR "© 1984 D. E. Knuth"
+#define MIKTEX_COMP_TM_STR "METAFONT is a trademark of Addison-Wesley Publishing Company"
 
 #include <miktex/Version>
