@@ -598,7 +598,11 @@ static void parse_options(int ac, char **av)
                  "etex      : Peter Breitenlohner, Phil Taylor and friends\n"
                  "omega     : John Plaice and Yannis Haralambous\n"
                  "aleph     : Giuseppe Bilotta\n"
+#if defined(MIKTEX)
+                 "pdftex    : Hàn Thế Thành and friends\n"
+#else
                  "pdftex    : Han The Thanh and friends\n"
+#endif
                  "kpathsea  : Karl Berry, Olaf Weber and others\n"
                  "lua       : Roberto Ierusalimschy, Waldemar Celes and Luiz Henrique de Figueiredo\n"
                  "metapost  : John Hobby, Taco Hoekwater, Luigi Scarso, Hans Hagen and friends\n"
@@ -1056,8 +1060,10 @@ static void mk_suffixlist(void)
 void lua_initialize(int ac, char **av)
 {
     char *given_file = NULL;
+#if !defined(MIKTEX)
     char *banner;
     size_t len;
+#endif
     int starttime;
     int utc;
     static char LC_CTYPE_C[] = "LC_CTYPE=C";
@@ -1068,13 +1074,19 @@ void lua_initialize(int ac, char **av)
     char *env_locale = NULL;
     char *tmp = NULL;
     /*tex Save to pass along to topenin. */
+#if !defined(MIKTEX)
     const char *fmt = "This is " MyName ", Version %s" WEB2CVERSION;
+#endif
     argc = ac;
     argv = av;
+#if defined(MIKTEX)
+    luatex_banner = miktex_banner(MyName, luatex_version_string);
+#else
     len = strlen(fmt) + strlen(luatex_version_string) ;
     banner = xmalloc(len);
     sprintf(banner, fmt, luatex_version_string);
     luatex_banner = banner;
+#endif
     kpse_invocation_name = kpse_program_basename(argv[0]);
     /*tex be `luac' */
     if (argc >1) {
