@@ -17,13 +17,30 @@
    Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307,
    USA.  */
 
+#include <string>
+
+#include <fmt/format.h>
+#include <fmt/ostream.h>
+
 #include <miktex/App/Application>
+#include <miktex/Core/Utils>
 
 #include "mpost.h"
 
 using namespace MiKTeX::App;
+using namespace MiKTeX::Core;
 
 void miktex_show_library_versions()
 {
   Application::GetApplication()->ShowLibraryVersions();
 }
+
+inline std::string GetBanner(const char* name, const char* version)
+{
+  return fmt::format("This is {0} {1} ({2})", name, version, Utils::GetMiKTeXBannerString());
+}
+
+void miktex_print_banner(FILE* file, const char* name, const char* version)
+{
+  fprintf(file, "%s\n", GetBanner(name, version).c_str());
+}
